@@ -1,10 +1,10 @@
-/* $Id: SUPDrvSem.cpp 118839 2017-10-28 15:14:05Z bird $ */
+/* $Id: SUPDrvSem.cpp 127855 2019-01-01 01:45:53Z bird $ */
 /** @file
  * VBoxDrv - The VirtualBox Support Driver - Common OS agnostic.
  */
 
 /*
- * Copyright (C) 2006-2017 Oracle Corporation
+ * Copyright (C) 2006-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -47,7 +47,7 @@
 
 #include <VBox/param.h>
 #include <VBox/log.h>
-#include <VBox/err.h>
+#include <iprt/errcore.h>
 
 
 /**
