@@ -1,4 +1,4 @@
-/* $Id: SUPLibAll.cpp 127855 2019-01-01 01:45:53Z bird $ */
+/* $Id: SUPLibAll.cpp 133675 2019-09-30 10:17:28Z bird $ */
 /** @file
  * VirtualBox Support Library - All Contexts Code.
  */
@@ -101,6 +101,48 @@ SUPDECL(uint64_t) SUPReadTscWithDelta(PSUPGLOBALINFOPAGE pGip)
             cTries++;
         }
     }
+    else if (pGip->fGetGipCpu & SUPGIPGETCPU_APIC_ID_EXT_0B)
+    {
+        /* Get APIC ID / 0x1b via the slow CPUID instruction, requires looping. */
+        uint32_t cTries = 0;
+        for (;;)
+        {
+            uint32_t idApic = ASMGetApicIdExt0B();
+            uTsc = ASMReadTSC();
+            if (RT_LIKELY(ASMGetApicIdExt0B() == idApic))
+            {
+                iGipCpu = pGip->aiCpuFromApicId[idApic];
+                break;
+            }
+            if (cTries >= 16)
+            {
+                iGipCpu = UINT16_MAX;
+                break;
+            }
+            cTries++;
+        }
+    }
+    else if (pGip->fGetGipCpu & SUPGIPGETCPU_APIC_ID_EXT_8000001E)
+    {
+        /* Get APIC ID / 0x8000001e via the slow CPUID instruction, requires looping. */
+        uint32_t cTries = 0;
+        for (;;)
+        {
+            uint32_t idApic = ASMGetApicIdExt8000001E();
+            uTsc = ASMReadTSC();
+            if (RT_LIKELY(ASMGetApicIdExt8000001E() == idApic))
+            {
+                iGipCpu = pGip->aiCpuFromApicId[idApic];
+                break;
+            }
+            if (cTries >= 16)
+            {
+                iGipCpu = UINT16_MAX;
+                break;
+            }
+            cTries++;
+        }
+    }
     else
     {
         /* Get APIC ID via the slow CPUID instruction, requires looping. */
@@ -203,6 +245,18 @@ DECLINLINE(uint16_t) supGetGipCpuIndex(PSUPGLOBALINFOPAGE pGip)
         iCpuSet  &= RTCPUSET_MAX_CPUS - 1;
         iGipCpu   = pGip->aiCpuFromCpuSetIdx[iCpuSet];
     }
+    else if (pGip->fGetGipCpu & SUPGIPGETCPU_APIC_ID_EXT_0B)
+    {
+        /* Get APIC ID via the slow CPUID/0000000B instruction. */
+        uint32_t idApic = ASMGetApicIdExt0B();
+        iGipCpu = pGip->aiCpuFromApicId[idApic];
+    }
+    else if (pGip->fGetGipCpu & SUPGIPGETCPU_APIC_ID_EXT_8000001E)
+    {
+        /* Get APIC ID via the slow CPUID/8000001E instruction. */
+        uint32_t idApic = ASMGetApicIdExt8000001E();
+        iGipCpu = pGip->aiCpuFromApicId[idApic];
+    }
     else
     {
         /* Get APIC ID via the slow CPUID instruction. */
