@@ -1,10 +1,10 @@
-/* $Id: heapsimple.cpp 118412 2017-10-17 14:26:02Z bird $ */
+/* $Id: heapsimple.cpp 127855 2019-01-01 01:45:53Z bird $ */
 /** @file
  * IPRT - A Simple Heap.
  */
 
 /*
- * Copyright (C) 2006-2017 Oracle Corporation
+ * Copyright (C) 2006-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -34,7 +34,7 @@
 
 #include <iprt/assert.h>
 #include <iprt/asm.h>
-#include <iprt/err.h>
+#include <iprt/errcore.h>
 #include <iprt/log.h>
 #include <iprt/string.h>
 #include <iprt/param.h>
