@@ -1,10 +1,10 @@
-/* $Id: handletable.h 118412 2017-10-17 14:26:02Z bird $ */
+/* $Id: handletable.h 127888 2019-01-01 06:31:29Z bird $ */
 /** @file
  * IPRT - Handle Tables, internal header.
  */
 
 /*
- * Copyright (C) 2008-2017 Oracle Corporation
+ * Copyright (C) 2008-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -24,6 +24,12 @@
  * terms and conditions of either the GPL or the CDDL or both.
  */
 
+#ifndef IPRT_INCLUDED_SRC_common_misc_handletable_h
+#define IPRT_INCLUDED_SRC_common_misc_handletable_h
+#ifndef RT_WITHOUT_PRAGMA_ONCE
+# pragma once
+#endif
+
 
 /*******************************************************************************
 *   Defined Constants And Macros                                               *
@@ -237,3 +243,5 @@ DECLINLINE(void) rtHandleTableUnlock(PRTHANDLETABLEINT pThis)
         RTSpinlockRelease(pThis->hSpinlock);
 }
 
+#endif /* !IPRT_INCLUDED_SRC_common_misc_handletable_h */
+
